# coding: utf-8

"""
    asset-lake-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class BaseEngine(str, Enum):
    """
    BaseEngine
    """

    """
    allowed enum values
    """
    TEXT_SLASH_LLAMA_MINUS_2_MINUS_7B_MINUS_CHAT = 'text/llama-2-7b-chat'
    TEXT_SLASH_LLAMA_MINUS_2_MINUS_13B_MINUS_CHAT = 'text/llama-2-13b-chat'
    TEXT_SLASH_LLAMA_MINUS_2_MINUS_70B_MINUS_CHAT = 'text/llama-2-70b-chat'
    TEXT_SLASH_CODELLAMA_MINUS_7B_MINUS_INSTRUCT = 'text/codellama-7b-instruct'
    TEXT_SLASH_CODELLAMA_MINUS_13B_MINUS_INSTRUCT = 'text/codellama-13b-instruct'
    TEXT_SLASH_CODELLAMA_MINUS_34B_MINUS_INSTRUCT = 'text/codellama-34b-instruct'
    TEXT_SLASH_CODELLAMA_MINUS_70B_MINUS_INSTRUCT = 'text/codellama-70b-instruct'
    TEXT_SLASH_MISTRAL_MINUS_7B_MINUS_INSTRUCT = 'text/mistral-7b-instruct'
    TEXT_SLASH_MIXTRAL_MINUS_8X7B_MINUS_INSTRUCT = 'text/mixtral-8x7b-instruct'
    IMAGE_SLASH_CONTROLNET_MINUS_SD15 = 'image/controlnet-sd15'
    IMAGE_SLASH_CONTROLNET_MINUS_SDXL = 'image/controlnet-sdxl'
    IMAGE_SLASH_STABLE_MINUS_DIFFUSION_MINUS_V1_MINUS_5 = 'image/stable-diffusion-v1-5'
    IMAGE_SLASH_STABLE_MINUS_DIFFUSION_MINUS_XL_MINUS_V1_MINUS_0 = 'image/stable-diffusion-xl-v1-0'
    IMAGE_SLASH_STABLE_MINUS_DIFFUSION_MINUS_SSD = 'image/stable-diffusion-ssd'
    AUDIO_SLASH_TORTOISE_MINUS_TTS = 'audio/tortoise-tts'
    AUDIO_SLASH_RVC = 'audio/rvc'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BaseEngine from a JSON string"""
        return cls(json.loads(json_str))


