# coding: utf-8

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
from clients.fine_tuning.models.lora_tune_checkpoint import LoraTuneCheckpoint
from clients.fine_tuning.models.lora_tune_file import LoraTuneFile
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class LoraTuneInput(BaseModel):
    """
    A LoRA Tune.
    """ # noqa: E501
    base_checkpoint: LoraTuneCheckpoint
    files: List[LoraTuneFile] = Field(description="The files used for this LoRA Tune.")
    resize_images: Optional[StrictBool] = None
    seed: Optional[StrictInt] = None
    steps: StrictInt = Field(description="The number of steps used for this LoRA Tune.")
    trigger_words: List[StrictStr] = Field(description="The trigger words used for this tune. As of now, only one trigger word is supported. `List` is used for future-proofing.")
    tune_type: Optional[Any] = Field(default=None, description="Tune type.")
    __properties: ClassVar[List[str]] = ["base_checkpoint", "files", "resize_images", "seed", "steps", "trigger_words", "tune_type"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LoraTuneInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of base_checkpoint
        if self.base_checkpoint:
            _dict['base_checkpoint'] = self.base_checkpoint.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item in self.files:
                if _item:
                    _items.append(_item.to_dict())
            _dict['files'] = _items
        # set to None if resize_images (nullable) is None
        # and model_fields_set contains the field
        if self.resize_images is None and "resize_images" in self.model_fields_set:
            _dict['resize_images'] = None

        # set to None if seed (nullable) is None
        # and model_fields_set contains the field
        if self.seed is None and "seed" in self.model_fields_set:
            _dict['seed'] = None

        # set to None if tune_type (nullable) is None
        # and model_fields_set contains the field
        if self.tune_type is None and "tune_type" in self.model_fields_set:
            _dict['tune_type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of LoraTuneInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "base_checkpoint": LoraTuneCheckpoint.from_dict(obj.get("base_checkpoint")) if obj.get("base_checkpoint") is not None else None,
            "files": [LoraTuneFile.from_dict(_item) for _item in obj.get("files")] if obj.get("files") is not None else None,
            "resize_images": obj.get("resize_images"),
            "seed": obj.get("seed"),
            "steps": obj.get("steps"),
            "trigger_words": obj.get("trigger_words"),
            "tune_type": obj.get("tune_type")
        })
        return _obj


