# coding: utf-8

"""
    asset-lake-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, field_validator
from clients.asset_lake.models.no_transfer_api import NoTransferApi
from clients.asset_lake.models.presigned_url_transfer_api import PresignedUrlTransferApi
from clients.asset_lake.models.sts_transfer_api import StsTransferApi
from typing import Union, Any, List, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal
from pydantic import StrictStr, Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

TRANSFERAPI_ONE_OF_SCHEMAS = ["NoTransferApi", "PresignedUrlTransferApi", "StsTransferApi"]

class TransferApi(BaseModel):
    """
    Asset transfer API.
    """
    # data type: PresignedUrlTransferApi
    oneof_schema_1_validator: Optional[PresignedUrlTransferApi] = None
    # data type: StsTransferApi
    oneof_schema_2_validator: Optional[StsTransferApi] = None
    # data type: NoTransferApi
    oneof_schema_3_validator: Optional[NoTransferApi] = None
    actual_instance: Optional[Union[NoTransferApi, PresignedUrlTransferApi, StsTransferApi]] = None
    one_of_schemas: List[str] = Literal["NoTransferApi", "PresignedUrlTransferApi", "StsTransferApi"]

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = TransferApi.model_construct()
        error_messages = []
        match = 0
        # validate data type: PresignedUrlTransferApi
        if not isinstance(v, PresignedUrlTransferApi):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PresignedUrlTransferApi`")
        else:
            match += 1
        # validate data type: StsTransferApi
        if not isinstance(v, StsTransferApi):
            error_messages.append(f"Error! Input type `{type(v)}` is not `StsTransferApi`")
        else:
            match += 1
        # validate data type: NoTransferApi
        if not isinstance(v, NoTransferApi):
            error_messages.append(f"Error! Input type `{type(v)}` is not `NoTransferApi`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in TransferApi with oneOf schemas: NoTransferApi, PresignedUrlTransferApi, StsTransferApi. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in TransferApi with oneOf schemas: NoTransferApi, PresignedUrlTransferApi, StsTransferApi. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # use oneOf discriminator to lookup the data type
        _data_type = json.loads(json_str).get("type")
        if not _data_type:
            raise ValueError("Failed to lookup data type from the field `type` in the input.")

        # check if data type is `NoTransferApi`
        if _data_type == "none":
            instance.actual_instance = NoTransferApi.from_json(json_str)
            return instance

        # check if data type is `PresignedUrlTransferApi`
        if _data_type == "presigned-url":
            instance.actual_instance = PresignedUrlTransferApi.from_json(json_str)
            return instance

        # check if data type is `StsTransferApi`
        if _data_type == "sts":
            instance.actual_instance = StsTransferApi.from_json(json_str)
            return instance

        # check if data type is `NoTransferApi`
        if _data_type == "NoTransferApi":
            instance.actual_instance = NoTransferApi.from_json(json_str)
            return instance

        # check if data type is `PresignedUrlTransferApi`
        if _data_type == "PresignedUrlTransferApi":
            instance.actual_instance = PresignedUrlTransferApi.from_json(json_str)
            return instance

        # check if data type is `StsTransferApi`
        if _data_type == "StsTransferApi":
            instance.actual_instance = StsTransferApi.from_json(json_str)
            return instance

        # deserialize data into PresignedUrlTransferApi
        try:
            instance.actual_instance = PresignedUrlTransferApi.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into StsTransferApi
        try:
            instance.actual_instance = StsTransferApi.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into NoTransferApi
        try:
            instance.actual_instance = NoTransferApi.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into TransferApi with oneOf schemas: NoTransferApi, PresignedUrlTransferApi, StsTransferApi. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into TransferApi with oneOf schemas: NoTransferApi, PresignedUrlTransferApi, StsTransferApi. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        to_dict = getattr(self.actual_instance, "to_dict", None)
        if callable(to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())


