# coding: utf-8

"""
    asset-lake-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic.v1 import BaseModel, Field, StrictStr

class ArchiverVolumeStorageRef(BaseModel):
    """
    ArchiverVolumeStorageRef
    """
    manifest_s3_md5: StrictStr = Field(..., description="Manifest S3 mdf. It matches the S3 ETag encoding.")
    manifest_s3_url: StrictStr = Field(..., description="Manifest S3 URL.")
    manifest_version: StrictStr = Field(..., description="Manifest version.")
    __properties = ["manifest_s3_md5", "manifest_s3_url", "manifest_version"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ArchiverVolumeStorageRef:
        """Create an instance of ArchiverVolumeStorageRef from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ArchiverVolumeStorageRef:
        """Create an instance of ArchiverVolumeStorageRef from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ArchiverVolumeStorageRef.parse_obj(obj)

        _obj = ArchiverVolumeStorageRef.parse_obj({
            "manifest_s3_md5": obj.get("manifest_s3_md5"),
            "manifest_s3_url": obj.get("manifest_s3_url"),
            "manifest_version": obj.get("manifest_version")
        })
        return _obj


