# coding: utf-8

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class TuneResult(BaseModel):
    """
    Tune result on worker.
    """ # noqa: E501
    number_of_available_assets: Optional[StrictInt] = None
    output_assets: Optional[List[StrictStr]] = None
    rejected_assets: Optional[List[StrictStr]] = None
    unready_assets: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["number_of_available_assets", "output_assets", "rejected_assets", "unready_assets"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TuneResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if number_of_available_assets (nullable) is None
        # and model_fields_set contains the field
        if self.number_of_available_assets is None and "number_of_available_assets" in self.model_fields_set:
            _dict['number_of_available_assets'] = None

        # set to None if output_assets (nullable) is None
        # and model_fields_set contains the field
        if self.output_assets is None and "output_assets" in self.model_fields_set:
            _dict['output_assets'] = None

        # set to None if rejected_assets (nullable) is None
        # and model_fields_set contains the field
        if self.rejected_assets is None and "rejected_assets" in self.model_fields_set:
            _dict['rejected_assets'] = None

        # set to None if unready_assets (nullable) is None
        # and model_fields_set contains the field
        if self.unready_assets is None and "unready_assets" in self.model_fields_set:
            _dict['unready_assets'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of TuneResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "number_of_available_assets": obj.get("number_of_available_assets"),
            "output_assets": obj.get("output_assets"),
            "rejected_assets": obj.get("rejected_assets"),
            "unready_assets": obj.get("unready_assets")
        })
        return _obj


